@@ -11,7 +11,7 @@ Business::GoCardless - Perl library for interacting with the GoCardless Basic v1
 
 =head1 VERSION
 
-0.13
+0.14
 
 =head1 DESCRIPTION
 
@@ -98,9 +98,7 @@ when given the necessary ENV variables.
 
 Any problems or errors will result in a Business::GoCardless::Exception
 object being thrown, so you should wrap any calls to the library in the
-appropriate error catching code (TryCatch in the below example):
-
-    use TryCatch;
+appropriate error catching code (ideally using a module from CPAN):
 
     try {
         my $Pager = $GoCardless->bills;
@@ -145,6 +143,9 @@ through all the objects:
 
 =cut
 
+use strict;
+use warnings;
+
 use Moo;
 with 'Business::GoCardless::Version';
 
